# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RetentionPolicySchema(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'duration': 'str',
        'replication': 'int',
        'retention_policy_name': 'str'
    }

    attribute_map = {
        'duration': 'duration',
        'replication': 'replication',
        'retention_policy_name': 'retention-policy-name'
    }

    def __init__(self, duration=None, replication=None, retention_policy_name=None):  # noqa: E501
        """RetentionPolicySchema - a model defined in Swagger"""  # noqa: E501

        self._duration = None
        self._replication = None
        self._retention_policy_name = None
        self.discriminator = None

        if duration is not None:
            self.duration = duration
        if replication is not None:
            self.replication = replication
        self.retention_policy_name = retention_policy_name

    @property
    def duration(self):
        """Gets the duration of this RetentionPolicySchema.  # noqa: E501

        Schedule duration in days or hours, Should be of pattern [1-9][0-9]*[dh]  # noqa: E501

        :return: The duration of this RetentionPolicySchema.  # noqa: E501
        :rtype: str
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this RetentionPolicySchema.

        Schedule duration in days or hours, Should be of pattern [1-9][0-9]*[dh]  # noqa: E501

        :param duration: The duration of this RetentionPolicySchema.  # noqa: E501
        :type: str
        """
        if duration is not None and not re.search(r'^[1-9][0-9]*[dh]$', duration):  # noqa: E501
            raise ValueError(r"Invalid value for `duration`, must be a follow pattern or equal to `/^[1-9][0-9]*[dh]$/`")  # noqa: E501

        self._duration = duration

    @property
    def replication(self):
        """Gets the replication of this RetentionPolicySchema.  # noqa: E501

        Number of independent copies if stored in the cluster  # noqa: E501

        :return: The replication of this RetentionPolicySchema.  # noqa: E501
        :rtype: int
        """
        return self._replication

    @replication.setter
    def replication(self, replication):
        """Sets the replication of this RetentionPolicySchema.

        Number of independent copies if stored in the cluster  # noqa: E501

        :param replication: The replication of this RetentionPolicySchema.  # noqa: E501
        :type: int
        """

        self._replication = replication

    @property
    def retention_policy_name(self):
        """Gets the retention_policy_name of this RetentionPolicySchema.  # noqa: E501

        Name of the retention-policy. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The retention_policy_name of this RetentionPolicySchema.  # noqa: E501
        :rtype: str
        """
        return self._retention_policy_name

    @retention_policy_name.setter
    def retention_policy_name(self, retention_policy_name):
        """Sets the retention_policy_name of this RetentionPolicySchema.

        Name of the retention-policy. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :param retention_policy_name: The retention_policy_name of this RetentionPolicySchema.  # noqa: E501
        :type: str
        """
        if retention_policy_name is None:
            raise ValueError("Invalid value for `retention_policy_name`, must not be `None`")  # noqa: E501
        if retention_policy_name is not None and len(retention_policy_name) > 64:
            raise ValueError("Invalid value for `retention_policy_name`, length must be less than or equal to `64`")  # noqa: E501
        if retention_policy_name is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', retention_policy_name):  # noqa: E501
            raise ValueError(r"Invalid value for `retention_policy_name`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._retention_policy_name = retention_policy_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RetentionPolicySchema, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RetentionPolicySchema):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaThenRetryBackoff(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'duration': 'str',
        'factor': 'int',
        'max_duration': 'str'
    }

    attribute_map = {
        'duration': 'duration',
        'factor': 'factor',
        'max_duration': 'max-duration'
    }

    def __init__(self, duration=None, factor=None, max_duration=None):  # noqa: E501
        """RuleSchemaThenRetryBackoff - a model defined in Swagger"""  # noqa: E501

        self._duration = None
        self._factor = None
        self._max_duration = None
        self.discriminator = None

        if duration is not None:
            self.duration = duration
        if factor is not None:
            self.factor = factor
        if max_duration is not None:
            self.max_duration = max_duration

    @property
    def duration(self):
        """Gets the duration of this RuleSchemaThenRetryBackoff.  # noqa: E501

        Initial duration to wait before retrying failed step  # noqa: E501

        :return: The duration of this RuleSchemaThenRetryBackoff.  # noqa: E501
        :rtype: str
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this RuleSchemaThenRetryBackoff.

        Initial duration to wait before retrying failed step  # noqa: E501

        :param duration: The duration of this RuleSchemaThenRetryBackoff.  # noqa: E501
        :type: str
        """

        self._duration = duration

    @property
    def factor(self):
        """Gets the factor of this RuleSchemaThenRetryBackoff.  # noqa: E501

        Wait duration multiplication factor during each retry attempt  # noqa: E501

        :return: The factor of this RuleSchemaThenRetryBackoff.  # noqa: E501
        :rtype: int
        """
        return self._factor

    @factor.setter
    def factor(self, factor):
        """Sets the factor of this RuleSchemaThenRetryBackoff.

        Wait duration multiplication factor during each retry attempt  # noqa: E501

        :param factor: The factor of this RuleSchemaThenRetryBackoff.  # noqa: E501
        :type: int
        """

        self._factor = factor

    @property
    def max_duration(self):
        """Gets the max_duration of this RuleSchemaThenRetryBackoff.  # noqa: E501

        Maximum duration to wait before retrying a failed step  # noqa: E501

        :return: The max_duration of this RuleSchemaThenRetryBackoff.  # noqa: E501
        :rtype: str
        """
        return self._max_duration

    @max_duration.setter
    def max_duration(self, max_duration):
        """Sets the max_duration of this RuleSchemaThenRetryBackoff.

        Maximum duration to wait before retrying a failed step  # noqa: E501

        :param max_duration: The max_duration of this RuleSchemaThenRetryBackoff.  # noqa: E501
        :type: str
        """

        self._max_duration = max_duration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaThenRetryBackoff, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaThenRetryBackoff):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SchedulerSchemaRepeat(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'every': 'str',
        'interval': 'SchedulerSchemaRepeatInterval',
        'never': 'list[object]'
    }

    attribute_map = {
        'every': 'every',
        'interval': 'interval',
        'never': 'never'
    }

    def __init__(self, every=None, interval=None, never=None):  # noqa: E501
        """SchedulerSchemaRepeat - a model defined in Swagger"""  # noqa: E501

        self._every = None
        self._interval = None
        self._never = None
        self.discriminator = None

        if every is not None:
            self.every = every
        if interval is not None:
            self.interval = interval
        if never is not None:
            self.never = never

    @property
    def every(self):
        """Gets the every of this SchedulerSchemaRepeat.  # noqa: E501

        Repeat every  # noqa: E501

        :return: The every of this SchedulerSchemaRepeat.  # noqa: E501
        :rtype: str
        """
        return self._every

    @every.setter
    def every(self, every):
        """Sets the every of this SchedulerSchemaRepeat.

        Repeat every  # noqa: E501

        :param every: The every of this SchedulerSchemaRepeat.  # noqa: E501
        :type: str
        """
        allowed_values = ["week", "day", "month", "year"]  # noqa: E501
        if every not in allowed_values:
            raise ValueError(
                "Invalid value for `every` ({0}), must be one of {1}"  # noqa: E501
                .format(every, allowed_values)
            )

        self._every = every

    @property
    def interval(self):
        """Gets the interval of this SchedulerSchemaRepeat.  # noqa: E501


        :return: The interval of this SchedulerSchemaRepeat.  # noqa: E501
        :rtype: SchedulerSchemaRepeatInterval
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this SchedulerSchemaRepeat.


        :param interval: The interval of this SchedulerSchemaRepeat.  # noqa: E501
        :type: SchedulerSchemaRepeatInterval
        """

        self._interval = interval

    @property
    def never(self):
        """Gets the never of this SchedulerSchemaRepeat.  # noqa: E501

        Never repeat scheduling  # noqa: E501

        :return: The never of this SchedulerSchemaRepeat.  # noqa: E501
        :rtype: list[object]
        """
        return self._never

    @never.setter
    def never(self, never):
        """Sets the never of this SchedulerSchemaRepeat.

        Never repeat scheduling  # noqa: E501

        :param never: The never of this SchedulerSchemaRepeat.  # noqa: E501
        :type: list[object]
        """

        self._never = never

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SchedulerSchemaRepeat, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SchedulerSchemaRepeat):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
